intelmq.bots.parsers.surbl package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.surbl package

## Submodules

## intelmq.bots.parsers.surbl.parser module

`intelmq.bots.parsers.surbl.parser.` `BOT`

  alias of `intelmq.bots.parsers.surbl.parser.SurblParserBot`

class `intelmq.bots.parsers.surbl.parser.` `SurblParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `process`()

## Module contents